==> abills-0.32.tgz: abills/language/russian.pl <==
$_TOTAL="";
$_NOT_EXIST=" ";
$_RECORDS="";
$_LOGIN="";
$_FUNCTIONS_LIST="";
$_USER_NOT_EXIST="   ";
$_END="";
$_CUSTOMERS="";
$_REVISION="";
$_LANGUAGE="";
$_HOLIDAYS="";
$_POSTPAID="";
$_NAME="";
$_SHOW="";
$_ANTISPAM="";
$_DELETE_USER="   ";
$_BACK_PAY="";
$_DELETED_USER=" ";
$_FIO="";
$_DAYS="";
$_BANK_INFO="";
$_VARIANT=" ";
$_TRAF_LIMIT=" ";
$_SA_ONLY="   ";
$_LOGINS="";
$_CREATED="";
$_REGISTRATION="";
$_CARD_SERVICE="  ";
$_COMPANY="";
$_GROUP="";
$_UPLIMIT="";
$_ADD="";
$_DATE="";
$_HANGUP="";
$_DEL="";
$_GENERED_PARRWORD=" ";
$ERR_SHORT_PASSWD=" .    6 ";
@MONTHES=('', '', '', '', '', '', '', '', '', '', '', '');;;;
$_YEAR="";
$_PAYMENT_NOTEXIST="  ";
$_SEND_MAIL=" e-mail";
$_SUBJECT="";
$_SPEED=" ";
$_TARIF_PLAN=" ";
$_TYPE="";
$_GO=" ";
$_FROM="";
$_TEST="";
$_MIN_SESSION_COST="  ";
$_BACK_MONEY=" ";
$_FILE="";
$_LOGOUT="";
$_ERROR_LOG=" ";
$_FOLDER="";
$_BYTE_TARIF=" ";
$_CREDITORS="";
$_MODULES=" ";
$_SELECT_USER=" ";
$_PARAMS="";
@WEEKDAYS=('', '', '', '', '', '', '', '');;;;
$_MESSAGES="";
$_CONFIRM_PASSWD=" ";
$_OPTIONS="";
$_ADDRESS="";
$_CHANGING=" ";
$_BANK_NAME=" ";
$_CREDIT="";
$_FEES=" ";
$_ACCESS=" ";
$_ACCOUNT_EXIST="  ";
$ERR_WRONG_CONFIRM="  ";
$_ENTER="";
$_HOUR_TARIF=" ";
$_ALL="";
$_LIST="";
$_NOT_ACTIVE=" ";
$_NETWORKS="";
$_ROWS="";
$_PORT="";
$_COMMENTS="";
$_CHANGED=" ";
$_ADMIN="";
$_LIMIT=" ";
$ERR_ENTER_USER_NAME="  ";
$_USED="";
$_EXCHANGE_RATE="  ";
$_RECV="";
$_TARIF_PLANS=" ";
$_TO="";
$_DOMAIN="";
$_LAST_LOGIN=" ";
$_DICTIONARY="";
$_TRAFFIC="";
$_TEXT="";
$_COUNT="";
$_STATE=" ";
$_SERVICES="";
$_STATS="";
$_SYSTEM=" ";
$_PERIOD="";
$_PAYMENT_ADDED="    ";
$_CHANGE_PASSWD=" ";
$_DUNES="  ";
$_DAY="";
$_NASS=" ";
$_FILTERS="";
$_NAS_STATISTIC="  ";
$_MONETARY_UNIT=" ";
$_INTERVALS="";
$_REMAIN="";
$_MAILBOXES=" ";
$_OTHER="";
$_SIMULTANEOUSLY="";
$_TAKE="";
$_PROFILE="";
$_RESULT="";
$_DURATION="";
$_SESSIONS="";
$_ADDRESS_STREET="";
$_GET="";
$_BANK_BIC="";
$_SHORT_NAME="";
$_ALIASES=" ";
$_MANAGE=" ";
$_TO_USER="";
$_MAKE_BACKAUP=" backaup";
$_NUM="";
$_ACTIVATE="";
$_PAYMENT_METHOD=" ";
$_SIZE="";
$_NO="";
$_ADDED="";
$_SEND="";
$_SUM="";
$_NO_SUM=" ";
$_ABON=" ";
$_WRONG_PASSWD="     ";
$_SEARCH="";
$ERR_NAME_TOOLONG="     ";
$_MESSAGES_DESCRIBE="  ,      ";
$_ORDER="";
$_AUTH="";
$_CONFIRM="";
$_MONTH="";
$_PASSWD="";
$_BEGIN="";
$_LAST=" ";
$_DOCS="";
$_ERROR=" ";
$_PREFIX=" ";
$_CONTRACT_ID=" ";
$_VARIANTS=" ";
$CHARSET=" windows-1251";
$_MONTH_FEE=".   ";
$_TEMPLATES="";
$_CLOSED="";
$_LOG="";
$_START="";
$_PAYMENT_TYPE=" ";
$_MONEY="  ";
$_REDUCTION="";
$_AVG=" ";
$_ADD_USER=" ";
$_DESCRIBE="";
$_GEN_PASSWD=" ";
$_SHOW_ALL="  ";
@PERIODS=('', '', '', '', ' ', ' ');;;;
$_ACTIV="";
$_TIME=" ";
$_PAYMENTS="";
$_SENDED="";
$_ALLOW="";
$_HOURS="";
$_EXPIRE="";
$ERR_WRONG_NAME=" ";
$_MAIL_BOX=" ";
$_RELAYS=" Relay,";
$_USER="";
$_BILLS=" ";
$_MIN="";
$_PRE=" ";
$_USER_INFO="  ";
$_NOW="";
$_SQL_BACKUP=" ";
$_REPLY=" ";
$_BILLING=" ";
$_DOMAINS="";
$_OCTETS_DIRECTION=" ";
$_ACCOUNT="";
$_ACCOUNTS=" ";
$_MESSAGE="";
$_CHANGE="";
$_DETAIL="";
$_NOT_LOGINED="   ";
$_PAY_CARDS="  ";
$_NAS=" ";
$_NAS_CONFIG="  ";
$_REPORTS=" ";
$_GETED="";
$_ALLOW_NAS="  ";
$_MONITORING="";
$_TRAFIC_TARIFS=" ";
$_ANTIVIRUS="";
$_MAX="";
$_ZAPED="Zaped";
$_DISABLE="";
$_CREATE="";
$_ICARDS="  ";
$_PER_MONTH=" ";
$_CREDIT_TRESSHOLD=" ";
$_CUSTOMER="";
$_INPAYMENTS="";
$_PARAM="";
$_DELETED="";
$_REFRESH="";
$_TRANSPORT=" ";
$ERR_SELECT_VARIANT=" ";
$_RESET="";
$_HOSTS="";
$_DEPOSIT="";
$_BALANCE="";
$_NO_RECORD=" ";
$_STATUS=" ";
$_WEEK="";
$_OPERATOR="";
$_YES="";
$_ADDRESS_BUILD="";
$_PERMISSION="";
$_AGE=" ";
$_VALUE="";
$_RESETED="";
$_TAX_NUMBER="";
$_PRINT="";
$_DAY_FEE=" /";
$_PHONE="";
$_EXIST="  ";
$_SESSION_ID=" ";
$_SHEDULE="";
$_WRONG_EMAIL=" e-mail ";
$_ROUTES="";
$_PREPAID="";
$_SENT="";
$_DEFAULT=" ";
$_SET="";
$_USER_EXIST="   ";
$_DAY_DURATION=" ";
$_LAST_PAYMENT=" ";
$_ALLOW_ALL=" ";
$_ADDRESS_FLAT="";
$_TIME_LIMIT=" ";
$_SDETAIL=" ";
$_ADMINS="";
$_USERS="";
$_GROUPS="";
$_BILL=" ";
$_WELCOME="";
$_INFO=" ";
$_PAYMENT_DELETED=" ";
$_COR_BANK_ACCOUNT=". ";
$_MAX_SESSION_DURATION="  ";
$_HANGUPED="";

==> abills-0.33.tgz: abills/language/russian.pl <==
$_TOTAL="";
$_NOT_EXIST=" ";
$_BRUTE_ATACK="--";
$_RECORDS="";
$_LOGIN="";
$_FUNCTIONS_LIST="";
$_USER_NOT_EXIST="   ";
$_END="";
$_CUSTOMERS="";
$_REVISION="";
$_LANGUAGE="";
$_HOLIDAYS="";
$_POSTPAID="";
$_NAME="";
$_SHOW="";
$_ANTISPAM="";
$_DELETE_USER="   ";
$_BACK_PAY="";
$_DELETED_USER=" ";
$_FIO="";
$_DAYS="";
$_BANK_INFO="";
$_VARIANT=" ";
$_TRAF_LIMIT=" ";
$_SA_ONLY="   ";
$_LOGINS="";
$_CREATED="";
$_REGISTRATION="";
$_CARD_SERVICE="  ";
$_COMPANY="";
$_GROUP="";
$_UPLIMIT="";
$_ADD="";
$_DATE="";
$_HANGUP="";
$_DEL="";
$_GENERED_PARRWORD=" ";
$ERR_SHORT_PASSWD=" .    6 ";
@MONTHES=('', '', '', '', '', '', '', '', '', '', '', '');;;;;
$_YEAR="";
$_PAYMENT_NOTEXIST="  ";
$_SEND_MAIL=" e-mail";
$_SERIAL="--";
$_SUBJECT="";
$_SPEED=" ";
$_TARIF_PLAN=" ";
$_TYPE="";
$_GO=" ";
$_FROM="";
$_TEST="";
$_MIN_SESSION_COST="  ";
$_BACK_MONEY=" ";
$_FILE="";
$_LOGOUT="";
$_ERROR_LOG=" ";
$_FOLDER="";
$_BYTE_TARIF=" ";
$_CREDITORS="";
$_MODULES=" ";
$_SELECT_USER=" ";
$_PARAMS="";
@WEEKDAYS=('', '', '', '', '', '', '', '');;;;;
$_MESSAGES="";
$_CONFIRM_PASSWD=" ";
$_OPTIONS="";
$_ADDRESS="";
$_CHANGING=" ";
$_BANK_NAME=" ";
$_CREDIT="";
$_FEES=" ";
$_ACCESS=" ";
$_ACCOUNT_EXIST="  ";
$ERR_WRONG_CONFIRM="  ";
$_ENTER="";
$_HOUR_TARIF=" ";
$_ALL="";
$_LIST="";
$_NOT_ACTIVE=" ";
$_NETWORKS="";
$_ROWS="";
$_PORT="";
$_COMMENTS="";
$_CHANGED=" ";
$_ADMIN="";
$_LIMIT=" ";
$ERR_ENTER_USER_NAME="  ";
$_USED="";
$_EXCHANGE_RATE="  ";
$_RECV="";
$_TARIF_PLANS=" ";
$_TO="";
$_DOMAIN="";
$_LAST_LOGIN=" ";
$_SYMBOLS="--";
$_DICTIONARY="";
$_TRAFFIC="";
$_TEXT="";
$_COUNT="";
$_STATE=" ";
$_SERVICES="";
$_STATS="";
$_SYSTEM=" ";
$_PERIOD="";
$_PAYMENT_ADDED="    ";
$_CHANGE_PASSWD=" ";
$_DUNES="  ";
$_DAY="";
$_NASS=" ";
$_FILTERS="";
$_NAS_STATISTIC="  ";
$_MONETARY_UNIT=" ";
$_INTERVALS="";
$_REMAIN="";
$_MAILBOXES=" ";
$_OTHER="";
$_SIMULTANEOUSLY="";
$_TAKE="";
$_PROFILE="";
$_RESULT="";
$_DURATION="";
$_SESSIONS="";
$_ADDRESS_STREET="";
$_GET="";
$_BANK_BIC="";
$_SHORT_NAME="";
$_ALIASES=" ";
$_LENGTH="--";
$_MANAGE=" ";
$_TO_USER="";
$_MAKE_BACKAUP=" backaup";
$_NUM="";
$_ACTIVATE="";
$_PAYMENT_METHOD=" ";
$_SIZE="";
$_NO="";
$_ADDED="";
$_SEND="";
$_SUM="";
$_NO_SUM=" ";
$_ABON=" ";
$_WRONG_PASSWD="     ";
$_SEARCH="";
$ERR_NAME_TOOLONG="     ";
$_MESSAGES_DESCRIBE="  ,      ";
$_ORDER="";
$_AUTH="";
$_CONFIRM="";
$_MONTH="";
$_PASSWD="";
$_BEGIN="";
$_LAST=" ";
$_DOCS="";
$_ERROR=" ";
$_PREFIX=" ";
$_VARIANTS=" ";
$_CONTRACT_ID=" ";
$CHARSET=" windows-1251";
$_MONTH_FEE=".   ";
$_TEMPLATES="";
$_CLOSED="";
$_LOG="";
$_START="";
$_PAYMENT_TYPE=" ";
$_MONEY="  ";
$_REDUCTION="";
$_AVG=" ";
$_ADD_USER=" ";
$_DESCRIBE="";
$_GEN_PASSWD=" ";
$_SHOW_ALL="  ";
@PERIODS=('', '', '', '', ' ', ' ');;;;;
$_ACTIV="";
$_TIME=" ";
$_PAYMENTS="";
$_SENDED="";
$_ALLOW="";
$_HOURS="";
$_EXPIRE="";
$ERR_WRONG_NAME=" ";
$_MAIL_BOX=" ";
$_RELAYS=" Relay,";
$_USER="";
$_BILLS=" ";
$_MIN="";
$_PRE=" ";
$_USER_INFO="  ";
$_NOW="";
$_SQL_BACKUP=" ";
$_REPLY=" ";
$_BILLING=" ";
$_DOMAINS="";
$_OCTETS_DIRECTION=" ";
$_ACCOUNT="";
$_ACCOUNTS=" ";
$_MESSAGE="";
$_CHANGE="";
$_DETAIL="";
$_NOT_LOGINED="   ";
$_PAY_CARDS="  ";
$_NAS=" ";
$_NAS_CONFIG="  ";
$_REPORTS=" ";
$_GETED="";
$_ALLOW_NAS="  ";
$_MONITORING="";
$_TRAFIC_TARIFS=" ";
$_ANTIVIRUS="";
$_MAX="";
$_ENABLE="--";
$_ZAPED="Zaped";
$_DISABLE="";
$_CREATE="";
$_ICARDS="  ";
$_PER_MONTH=" ";
$_CREDIT_TRESSHOLD=" ";
$_CUSTOMER="";
$_INPAYMENTS="";
$_PARAM="";
$_DELETED="";
$_REFRESH="";
$_TRANSPORT=" ";
$ERR_SELECT_VARIANT=" ";
$_RESET="";
$_HOSTS="";
$_DEPOSIT="";
$_BALANCE="";
$_NO_RECORD=" ";
$_STATUS=" ";
$_WEEK="";
$_OPERATOR="";
$_YES="";
$_ADDRESS_BUILD="";
$_PERMISSION="";
$_AGE=" ";
$_VALUE="";
$_RESETED="";
$_TAX_NUMBER="";
$_PRINT="";
$_DAY_FEE=" /";
$_PHONE="";
$_EXIST="  ";
$_SESSION_ID=" ";
$_WRONG_EMAIL=" e-mail ";
$_SHEDULE="";
$_ROUTES="";
$_PREPAID="";
$_SENT="";
$_DEFAULT=" ";
$_SET="";
$_USER_EXIST="   ";
$_DAY_DURATION=" ";
$_LAST_PAYMENT=" ";
$_ALLOW_ALL=" ";
$_ADDRESS_FLAT="";
$_TIME_LIMIT=" ";
$_SDETAIL=" ";
$_ADMINS="";
$_USERS="";
$_GROUPS="";
$_BILL=" ";
$_INFO=" ";
$_WELCOME="";
$_PAYMENT_DELETED=" ";
$_COR_BANK_ACCOUNT=". ";
$_MAX_SESSION_DURATION="  ";
$_HANGUPED="";
